pub struct DefaultEngine<ET>where
ET: EngineTypes,{
pub aux: EngineAux<ET>,
pub state: <ET as EngineTypes>::State,
pub filesystem: <ET as EngineTypes>::FileSystem,
pub fontsystem: <ET as EngineTypes>::FontSystem,
pub mouth: <ET as EngineTypes>::Mouth,
pub gullet: <ET as EngineTypes>::Gullet,
pub stomach: <ET as EngineTypes>::Stomach,
}Expand description
Default implementation of a TeXEngine for the provided EngineTypes.
Fields
aux: EngineAux<ET>state: <ET as EngineTypes>::Statefilesystem: <ET as EngineTypes>::FileSystemfontsystem: <ET as EngineTypes>::FontSystemmouth: <ET as EngineTypes>::Mouthgullet: <ET as EngineTypes>::Gulletstomach: <ET as EngineTypes>::StomachTrait Implementations
Sourceimpl<ET> Default for DefaultEngine<ET>where
ET: EngineTypes,
impl<ET> Default for DefaultEngine<ET>where
ET: EngineTypes,
Sourcefn default() -> DefaultEngine<ET>
fn default() -> DefaultEngine<ET>
Returns the โdefault valueโ for a type. Read more
impl RusTeXEngineExt for DefaultEngine<Types>
impl RusTeXEngineExt for DefaultEngine<Types>
impl RusTeXEngineT for DefaultEngine<Types>
impl RusTeXEngineT for DefaultEngine<Types>
Sourceimpl<ET> TeXEngine for DefaultEngine<ET>where
ET: EngineTypes,
impl<ET> TeXEngine for DefaultEngine<ET>where
ET: EngineTypes,
type Types = ET
Sourcefn get_engine_refs(&mut self) -> EngineReferences<'_, ET>
fn get_engine_refs(&mut self) -> EngineReferences<'_, ET>
Returns mutable references to the components of the engine.
Sourcefn do_file_default<F>(
&mut self,
s: &str,
f: F,
) -> Result<(), TeXError<Self::Types>>
fn do_file_default<F>( &mut self, s: &str, f: F, ) -> Result<(), TeXError<Self::Types>>
Compile a
.tex file. All finished pages are passed to the provided continuation. Read moreSourcefn initialize_tex_primitives(&mut self)
fn initialize_tex_primitives(&mut self)
Registers all primitives of plain TeX and sets the default variables.
Sourcefn initialize_plain_tex(&mut self) -> Result<(), TeXError<Self::Types>>
fn initialize_plain_tex(&mut self) -> Result<(), TeXError<Self::Types>>
Initialize the engine by processing
plain.tex. Read moreSourcefn initialize_etex_primitives(&mut self)
fn initialize_etex_primitives(&mut self)
Registers all primitives of plain TeX, e-TeX and sets the default variables.
Sourcefn initialize_eplain_tex(&mut self) -> Result<(), TeXError<Self::Types>>
fn initialize_eplain_tex(&mut self) -> Result<(), TeXError<Self::Types>>
Initialize the engine by processing
eplain.tex. Read moreSourcefn load_latex(&mut self) -> Result<(), TeXError<Self::Types>>
fn load_latex(&mut self) -> Result<(), TeXError<Self::Types>>
Initialized the engine by processing
latex.ltx. Only call this (for modern LaTeX setups)
after calling initialize_etex_primitives first. Read moreAuto Trait Implementations
impl<ET> Freeze for DefaultEngine<ET>where
<ET as EngineTypes>::State: Freeze,
<ET as EngineTypes>::FileSystem: Freeze,
<ET as EngineTypes>::FontSystem: Freeze,
<ET as EngineTypes>::Mouth: Freeze,
<ET as EngineTypes>::Gullet: Freeze,
<ET as EngineTypes>::Stomach: Freeze,
<ET as EngineTypes>::ErrorHandler: Freeze,
<ET as EngineTypes>::Outputs: Freeze,
<ET as EngineTypes>::Extension: Freeze,
<<ET as EngineTypes>::CSName as CSName<<ET as EngineTypes>::Char>>::Handler: Freeze,
impl<ET> RefUnwindSafe for DefaultEngine<ET>where
<ET as EngineTypes>::State: RefUnwindSafe,
<ET as EngineTypes>::FileSystem: RefUnwindSafe,
<ET as EngineTypes>::FontSystem: RefUnwindSafe,
<ET as EngineTypes>::Mouth: RefUnwindSafe,
<ET as EngineTypes>::Gullet: RefUnwindSafe,
<ET as EngineTypes>::Stomach: RefUnwindSafe,
<ET as EngineTypes>::ErrorHandler: RefUnwindSafe,
<ET as EngineTypes>::Outputs: RefUnwindSafe,
<ET as EngineTypes>::Extension: RefUnwindSafe,
<<ET as EngineTypes>::CSName as CSName<<ET as EngineTypes>::Char>>::Handler: RefUnwindSafe,
<ET as EngineTypes>::Token: RefUnwindSafe,
impl<ET> Send for DefaultEngine<ET>where
<ET as EngineTypes>::State: Send,
<ET as EngineTypes>::FileSystem: Send,
<ET as EngineTypes>::FontSystem: Send,
<ET as EngineTypes>::Mouth: Send,
<ET as EngineTypes>::Gullet: Send,
<ET as EngineTypes>::Stomach: Send,
<ET as EngineTypes>::ErrorHandler: Send,
<ET as EngineTypes>::Outputs: Send,
<ET as EngineTypes>::Extension: Send,
<<ET as EngineTypes>::CSName as CSName<<ET as EngineTypes>::Char>>::Handler: Send,
impl<ET> Sync for DefaultEngine<ET>where
<ET as EngineTypes>::State: Sync,
<ET as EngineTypes>::FileSystem: Sync,
<ET as EngineTypes>::FontSystem: Sync,
<ET as EngineTypes>::Mouth: Sync,
<ET as EngineTypes>::Gullet: Sync,
<ET as EngineTypes>::Stomach: Sync,
<ET as EngineTypes>::ErrorHandler: Sync,
<ET as EngineTypes>::Outputs: Sync,
<ET as EngineTypes>::Extension: Sync,
<<ET as EngineTypes>::CSName as CSName<<ET as EngineTypes>::Char>>::Handler: Sync,
impl<ET> Unpin for DefaultEngine<ET>where
<ET as EngineTypes>::State: Unpin,
<ET as EngineTypes>::FileSystem: Unpin,
<ET as EngineTypes>::FontSystem: Unpin,
<ET as EngineTypes>::Mouth: Unpin,
<ET as EngineTypes>::Gullet: Unpin,
<ET as EngineTypes>::Stomach: Unpin,
<ET as EngineTypes>::ErrorHandler: Unpin,
<ET as EngineTypes>::Outputs: Unpin,
<ET as EngineTypes>::Extension: Unpin,
<<ET as EngineTypes>::CSName as CSName<<ET as EngineTypes>::Char>>::Handler: Unpin,
<ET as EngineTypes>::Token: Unpin,
impl<ET> UnsafeUnpin for DefaultEngine<ET>where
<ET as EngineTypes>::State: UnsafeUnpin,
<ET as EngineTypes>::FileSystem: UnsafeUnpin,
<ET as EngineTypes>::FontSystem: UnsafeUnpin,
<ET as EngineTypes>::Mouth: UnsafeUnpin,
<ET as EngineTypes>::Gullet: UnsafeUnpin,
<ET as EngineTypes>::Stomach: UnsafeUnpin,
<ET as EngineTypes>::ErrorHandler: UnsafeUnpin,
<ET as EngineTypes>::Outputs: UnsafeUnpin,
<ET as EngineTypes>::Extension: UnsafeUnpin,
<<ET as EngineTypes>::CSName as CSName<<ET as EngineTypes>::Char>>::Handler: UnsafeUnpin,
impl<ET> UnwindSafe for DefaultEngine<ET>where
<ET as EngineTypes>::State: UnwindSafe,
<ET as EngineTypes>::FileSystem: UnwindSafe,
<ET as EngineTypes>::FontSystem: UnwindSafe,
<ET as EngineTypes>::Mouth: UnwindSafe,
<ET as EngineTypes>::Gullet: UnwindSafe,
<ET as EngineTypes>::Stomach: UnwindSafe,
<ET as EngineTypes>::ErrorHandler: UnwindSafe,
<ET as EngineTypes>::Outputs: UnwindSafe,
<ET as EngineTypes>::Extension: UnwindSafe,
<<ET as EngineTypes>::CSName as CSName<<ET as EngineTypes>::Char>>::Handler: UnwindSafe,
<ET as EngineTypes>::Token: UnwindSafe,