Struct Fontsystem
pub struct Fontsystem {
fs: TfmFontSystem<i32, Dim32, (NonZero<u32>, PhantomData<u8>)>,
pub glyphmaps: FontInfoStore<String, fn(&str) -> String>,
}Fields
fs: TfmFontSystem<i32, Dim32, (NonZero<u32>, PhantomData<u8>)>glyphmaps: FontInfoStore<String, fn(&str) -> String>Trait Implementations
impl Clone for Fontsystem
impl Clone for Fontsystem
fn clone(&self) -> Fontsystem
fn clone(&self) -> Fontsystem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for Fontsystem
impl Debug for Fontsystem
impl FontSystem for Fontsystem
impl FontSystem for Fontsystem
type Font = Arc<TfmFontI<i32, Dim32, (NonZero<u32>, PhantomData<u8>)>>
type Font = Arc<TfmFontI<i32, Dim32, (NonZero<u32>, PhantomData<u8>)>>
The type of
Fonts provided by this font system.type CS = (NonZero<u32>, PhantomData<u8>)
type CS = (NonZero<u32>, PhantomData<u8>)
The type of control sequences used to give a name to a font; returned by e.g.
\the when followed
by a font.fn new<ET>(aux: &mut EngineAux<ET>) -> Fontsystemwhere
ET: EngineTypes<Char = <Fontsystem as FontSystem>::Char, CSName = <Fontsystem as FontSystem>::CS>,
fn new<ET>(aux: &mut EngineAux<ET>) -> Fontsystemwhere
ET: EngineTypes<Char = <Fontsystem as FontSystem>::Char, CSName = <Fontsystem as FontSystem>::CS>,
Creates a new font system.
fn new_font<S, F>(
&mut self,
path: S,
macroname: <<Fontsystem as FontSystem>::Font as Font>::CS,
fs: &mut F,
) -> <Fontsystem as FontSystem>::Font
fn new_font<S, F>( &mut self, path: S, macroname: <<Fontsystem as FontSystem>::Font as Font>::CS, fs: &mut F, ) -> <Fontsystem as FontSystem>::Font
Creates a new font with the given macroname and filepath (in plain TeX a
.tfm-file).fn null(&self) -> <Fontsystem as FontSystem>::Font
fn null(&self) -> <Fontsystem as FontSystem>::Font
Returns the
\nullfont.Auto Trait Implementations
impl Freeze for Fontsystem
impl RefUnwindSafe for Fontsystem
impl Send for Fontsystem
impl Sync for Fontsystem
impl Unpin for Fontsystem
impl UnwindSafe for Fontsystem